@@ -14,9 +14,12 @@ lazy_static! {
                 ("AAVE/USDT", 0.1_f64),
                 ("ACH/USDT", 10_f64),
                 ("ADA/USDT", 10_f64),
+                ("AGLD/USDT", 1_f64),
                 ("AKRO/USDT", 100_f64),
                 ("ALGO/USDT", 10_f64),
+                ("ALICE/USDT", 0.1_f64),
                 ("ANKR/USDT", 10_f64),
+                ("AR/USDT", 0.1_f64),
                 ("ATOM/USDT", 1_f64),
                 ("AVAX/USDT", 1_f64),
                 ("AXS/USDT", 0.1_f64),
@@ -33,6 +36,7 @@ lazy_static! {
                 ("BTC/USDT", 0.001_f64),
                 ("BTS/USDT", 100_f64),
                 ("BTT/USDT", 1000_f64),
+                ("C98/USDT", 1_f64),
                 ("CHR/USDT", 10_f64),
                 ("CHZ/USDT", 10_f64),
                 ("CLV/USDT", 1_f64),
@@ -46,6 +50,8 @@ lazy_static! {
                 ("DASH/USDT", 0.1_f64),
                 ("DOGE/USDT", 100_f64),
                 ("DOT/USDT", 1_f64),
+                ("DYDX/USDT", 0.1_f64),
+                ("EGLD/USDT", 0.01_f64),
                 ("ENJ/USDT", 1_f64),
                 ("EOS/USDT", 1_f64),
                 ("ETC/USDT", 1_f64),
@@ -54,6 +60,8 @@ lazy_static! {
                 ("FLOW/USDT", 0.1_f64),
                 ("FORTH/USDT", 0.1_f64),
                 ("FRONT/USDT", 1_f64),
+                ("FTT/USDT", 0.01_f64),
+                ("GALA/USDT", 10_f64),
                 ("GRT/USDT", 10_f64),
                 ("HBAR/USDT", 10_f64),
                 ("ICP/USDT", 0.01_f64),
@@ -81,10 +89,12 @@ lazy_static! {
                 ("NKN/USDT", 10_f64),
                 ("O3/USDT", 1_f64),
                 ("OGN/USDT", 1_f64),
+                ("OKB/USDT", 0.1_f64),
                 ("OMG/USDT", 1_f64),
                 ("ONE/USDT", 100_f64),
                 ("ONT/USDT", 10_f64),
                 ("PHA/USDT", 1_f64),
+                ("QNT/USDT", 0.01_f64),
                 ("QTUM/USDT", 1_f64),
                 ("REEF/USDT", 100_f64),
                 ("REN/USDT", 10_f64),
@@ -110,6 +120,7 @@ lazy_static! {
                 ("WAXP/USDT", 10_f64),
                 ("WOO/USDT", 10_f64),
                 ("XCH/USDT", 0.001_f64),
+                ("XEC/USDT", 10000_f64),
                 ("XEM/USDT", 10_f64),
                 ("XLM/USDT", 10_f64),
                 ("XMR/USDT", 0.01_f64),
