@@ -14,8 +14,10 @@ lazy_static! {
             ("AAVE/USDT", 0.01_f64),
             ("ADA/USDT", 10_f64),
             ("ALGO/USDT", 1_f64),
+            ("ALICE/USDT", 0.1_f64),
             ("ATOM/USDT", 0.1_f64),
             ("AVAX/USDT", 0.1_f64),
+            ("AXS/USDT", 0.1_f64),
             ("BAND/USDT", 0.1_f64),
             ("BAT/USDT", 1_f64),
             ("BCH/USDT", 0.01_f64),
@@ -23,6 +25,7 @@ lazy_static! {
             ("BSV/USDT", 0.01_f64),
             ("BTC/USDT", 0.001_f64),
             ("BTT/USDT", 1000_f64),
+            ("C98/USDT", 1_f64),
             ("CHZ/USDT", 1_f64),
             ("COMP/USDT", 0.01_f64),
             ("CRV/USDT", 1_f64),
@@ -31,6 +34,8 @@ lazy_static! {
             ("DGB/USDT", 10_f64),
             ("DOGE/USDT", 100_f64),
             ("DOT/USDT", 1_f64),
+            ("DYDX/USDT", 0.1_f64),
+            ("EGLD/USDT", 0.01_f64),
             ("ENJ/USDT", 1_f64),
             ("EOS/USDT", 1_f64),
             ("ETC/USDT", 0.1_f64),
@@ -38,6 +43,7 @@ lazy_static! {
             ("FIL/USDT", 0.1_f64),
             ("FTM/USDT", 1_f64),
             ("GRT/USDT", 1_f64),
+            ("HBAR/USDT", 10_f64),
             ("ICP/USDT", 0.01_f64),
             ("IOST/USDT", 100_f64),
             ("KSM/USDT", 0.01_f64),
@@ -48,11 +54,14 @@ lazy_static! {
             ("MATIC/USDT", 10_f64),
             ("MIR/USDT", 0.1_f64),
             ("MKR/USDT", 0.001_f64),
+            ("NEAR/USDT", 0.1_f64),
             ("NEO/USDT", 0.1_f64),
             ("OCEAN/USDT", 1_f64),
+            ("ONE/USDT", 10_f64),
             ("ONT/USDT", 1_f64),
             ("QTUM/USDT", 0.1_f64),
             ("RVN/USDT", 10_f64),
+            ("SAND/USDT", 1_f64),
             ("SHIB/USDT", 100000_f64),
             ("SNX/USDT", 0.1_f64),
             ("SOL/USDT", 0.1_f64),
@@ -69,6 +78,7 @@ lazy_static! {
             ("XRP/USDT", 10_f64),
             ("XTZ/USDT", 1_f64),
             ("YFI/USDT", 0.0001_f64),
+            ("YGG/USDT", 0.1_f64),
             ("ZEC/USDT", 0.01_f64),
         ]
         .into_iter()
