@@ -47,6 +47,7 @@ lazy_static! {
             ("CRV/USDT", 0.1_f64),
             ("CSPR/USDT", 1_f64),
             ("CTK/USDT", 1_f64),
+            ("CTSI/USDT", 1_f64),
             ("CVC/USDT", 1_f64),
             ("DASH/USDT", 0.01_f64),
             ("DENT/USDT", 1_f64),
@@ -54,6 +55,7 @@ lazy_static! {
             ("DOGE/USDT", 100_f64),
             ("DOT/USDT", 0.1_f64),
             ("DYDX/USDT", 1_f64),
+            ("EDEN/USDT", 1_f64),
             ("EGLD/USDT", 0.1_f64),
             ("ENJ/USDT", 1_f64),
             ("EOS/USDT", 0.1_f64),
@@ -97,6 +99,7 @@ lazy_static! {
             ("NEAR/USDT", 1_f64),
             ("NEO/USDT", 0.1_f64),
             ("NKN/USDT", 1_f64),
+            ("NU/USDT", 1_f64),
             ("O3/USDT", 1_f64),
             ("OCEAN/USDT", 1_f64),
             ("OGN/USDT", 1_f64),
